@@ -1,4 +1,4 @@
-from owslib.sml import SensorML
+from owslib.swe.sensor.sml import SensorML
 
 class IoosDescribeSensor(SensorML):
     def get_true(self):
